acdh\_collatex\_utils package
=============================

Submodules
----------

acdh\_collatex\_utils.acdh\_collatex\_utils module
--------------------------------------------------

.. automodule:: acdh_collatex_utils.acdh_collatex_utils
    :members:
    :undoc-members:
    :show-inheritance:

acdh\_collatex\_utils.cli module
--------------------------------

.. automodule:: acdh_collatex_utils.cli
    :members:
    :undoc-members:
    :show-inheritance:

acdh\_collatex\_utils.collatex\_patch module
--------------------------------------------

.. automodule:: acdh_collatex_utils.collatex_patch
    :members:
    :undoc-members:
    :show-inheritance:

acdh\_collatex\_utils.xml module
--------------------------------

.. automodule:: acdh_collatex_utils.xml
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: acdh_collatex_utils
    :members:
    :undoc-members:
    :show-inheritance:
